@@ -7,7 +7,7 @@ from rdr import *
 @click.command( options_metavar='[<options>]' )
 @click.option('-w', '--width', default=80, help='number of characters in each line of output')
 @click.option('-l', '--lines', default=999, help='number of lines of text to output')
-@click.option('-q', '--query', default='love', help='output in a more human-readable form')
+@click.option('-q', '--query', default='love', help='a word for phrase')
 @click.argument( 'carrel', metavar='<carrel>' )
 def concordance( carrel, query, width, lines ) :
 
@@ -15,7 +15,11 @@ def concordance( carrel, query, width, lines ) :
 	
 	Given a query, this subcommand will search <carrel> and return a list of results where each result is a set of words to the left of query, the query, and a set of words to the right of query -- a keyword-in-context index. This is useful for answering the question, "What words are used in the same breath as the given word?" The query can be a phrase.
 	
-	Examples: rdr concordance homer -q hector; rdr concordance homer -q 'hector was'
+	Examples:
+	
+	\b
+	  rdr concordance homer -q hector
+	  rdr concordance homer -q 'hector was'
 
 	See also: rdr ngrams --help"""
 	
